# `{self.name}`

<p align="center">
    <a href="https://pypi.python.org/pypi/{self.name}"><img alt="PyPI" src="https://img.shields.io/pypi/v/{self.name}.svg"></a>
	<a href="https://pypi.python.org/pypi/{self.name}"><img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/{self.name}.svg"></a>
    <a href="https://pepy.tech/project/{self.name}"><img alt="Downloads" src="https://pepy.tech/badge/{self.name}"></a>
    <a href="#Contribution" title="Contributions are welcome"><img src="https://img.shields.io/badge/contributions-welcome-green.svg"></a>
    <a href="https://github.com/{self.Github_username}/{self.name}/releases" title="{self.name}"><img src="https://img.shields.io/github/release-date/{self.Github_username}/{self.name}?color=green&label=updated"></a>
    <img alt="PyPI - License" src="https://img.shields.io/pypi/l/{self.name}">
    <img alt="PyPI - Status" src="https://img.shields.io/pypi/status/{self.name}">
    <img alt="GitHub Repo stars" src="https://img.shields.io/github/stars/{self.Github_username}/{self.name}">
    <a href="https://twitter.com/@{self.Github_username}" title="Follow us on Twitter"><img src="https://img.shields.io/twitter/follow/{self.Github_username}.svg?style=social&label=Follow"></a>
</p>

![Replace with your own inspirational logo here](https://github.com/PFython/easypypi/blob/main/easypypi.png?raw=true)

## CONTENTS

1. [OVERVIEW](#1.-OVERVIEW)
2. [INSTALLATION](#2.-INSTALLATION)
3. [BASIC USE](#3.-BASIC-USE)
4. [UNDER THE BONNET](#4.-UNDER-THE-BONNET)
5. [CONTRIBUTING](#5.-CONTRIBUTING)
6. [CREDITS](#6.-CREDITS)
7. [PAYING IT FORWARD](#7.-PAYING-IT-FORWARD)


## 1. OVERVIEW
{self.description}

## 2. INSTALLATION

    pip install {self.name}


## 3. BASIC USE

    >>> import {self.name}


## 4. UNDER THE BONNET

Describe any important inner workings of your Package, including API details.

## 5. CONTRIBUTING

Contact {self.author} {self.email} or feel free to raise Pull Requests / Issue in the normal Github way.

## 6. CREDITS

Who helped you or inspired you?  What other packages are you using or have you modified?

## 7. PAYING IT FORWARD

If `{self.name}` helps you save time and focus on more important things, please feel free to to show your appreciation by starring the repository on Github.

I'd also be delighted if you wanted to:

<a href="https://www.buymeacoffee.com/{self.Github_username}" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/v2/arial-yellow.png" alt="Buy Me A Coffee" width="217px" ></a>
